local Boat = ...

--------------------------------------------------------------------------
local HARBOUR_COMP_SAIL = {
	TypeName = HarbourPrefix .. "_COMP_SAIL",
	ParentType = "COMPONENT",
	Properties = {
                { Name = "SailScaleFactor", Type = "float", Default = 0 },
                { Name = "SailPeriod", Type = "float", Default = 3 },
                { Name = "windBlow", Type = "boolean", Default = false },
		}
}

--[[
--------------------------------------------------------------------------
function HARBOUR_COMP_SAIL:startWind()
    self.windBlow = true
end
--------------------------------------------------------------------------
function HARBOUR_COMP_SAIL:stopWind()
    self.windBlow = false
end
--]]

--------------------------------------------------------------------------
function HARBOUR_COMP_SAIL:create()
end

--------------------------------------------------------------------------
function HARBOUR_COMP_SAIL:init()
    self._scale = 1
    self._delta = 1
    self._timer = self.SailPeriod
end

--------------------------------------------------------------------------
function HARBOUR_COMP_SAIL:update()
    if not self.windBlow then
        self:getOwner():scale({1/self._delta, 1, 1})
        self._delta = 1
        return
    end

    local dt = self:getLevel():getDeltaTime()

    self._timer = self._timer - dt 
--    Boat:log("self.SailScaleFactor = " .. self.SailScaleFactor .. " _timer = " .. self._timer .. " dt = " .. dt .. " delta = " .. tostring(self._delta))
    if self._timer < 0 then
        if self.SailScaleFactor<0 then
--           Boat:log("restore scale")
           self:getOwner():scale({1/self._delta, 1, 1})
           self._delta = 1
        end
        self.SailScaleFactor = -self.SailScaleFactor
        self._timer = self.SailPeriod
    end
    local _scale = 1
    local nextDelta = 1
    if self.SailScaleFactor < 0 then
        _scale = 1/(1 - self.SailScaleFactor*dt/self.SailPeriod)
        nextDelta = self._delta*_scale
--        Boat:log("self.SailScaleFactor = " .. self.SailScaleFactor .. " nextDelta = " .. nextDelta .. " scale = " .. _scale)
        if nextDelta<1 then
            self._timer = -1 -- force an end of loop
            return
        end    
    else
        _scale = 1 + self.SailScaleFactor*dt/self.SailPeriod
        nextDelta = self._delta*_scale
--        Boat:log("self.SailScaleFactor = " .. self.SailScaleFactor .. " nextDelta = " .. nextDelta .. " scale = " .. _scale)
        if nextDelta>(1+self.SailScaleFactor) then
            return -- wait untill the end of the timer
        end    
    end
--    Boat:log("self.SailScaleFactor = " .. self.SailScaleFactor .. " SailPeriod = " .. self.SailPeriod .. " dt = " .. dt .. " scale = " .. tostring(self._scale))
    self:getOwner():scale({_scale, 1, 1})
    self._delta = nextDelta
 end

--------------------------------------------------------------------------
Boat:registerClass(HARBOUR_COMP_SAIL)
